@@ -1,6 +1,7 @@
 use strict;
 use warnings;
-package Hash::MostUtils::leach;
+package
+	Hash::MostUtils::leach; # don't index me, please
 
 use provide (
   if    => ge => 5.013 => 'Hash::MostUtils::leach::v5_13',
@@ -11,6 +12,7 @@ use Scalar::Util qw(refaddr);
 
 {
   my %end;
+  my %size;
 
   # n-ary each for lists
   sub _n_each {
@@ -23,6 +25,16 @@ use Scalar::Util qw(refaddr);
     $data = [ %$data ] if
       do { local $@; eval { scalar keys %$data; 1 } };
 
+    # did the size change? if so, zero out our %end
+    if (exists $size{$ident}) {
+      if ($size{$ident} != $#{$data}) {
+	$size{$ident} = $#{$data};
+	$end{$ident} = 0;
+      }
+    } else {
+      $size{$ident} = $#{$data};
+    }
+
     if ($#{$data} < ($end{$ident} || 0)) {
       delete $end{$ident};
       return ();
